@@ -22,6 +22,8 @@
 #include <KConfigGroup>
 #include <KDesktopFile>
 #include <KFileItemListProperties>
+#include <KJobUiDelegate>
+#include "mockcoredelegateextensions.h"
 
 Q_DECLARE_METATYPE(Qt::KeyboardModifiers)
 Q_DECLARE_METATYPE(Qt::DropAction)
@@ -36,13 +38,14 @@ void initLocale()
 Q_CONSTRUCTOR_FUNCTION(initLocale)
 #endif
 
+
 class JobSpy : public QObject
 {
     Q_OBJECT
 public:
     JobSpy(KIO::Job *job)
         : QObject(nullptr),
-          m_spy(job, SIGNAL(result(KJob*))),
+          m_spy(job, &KJob::result),
           m_error(0)
     {
         connect(job, &KJob::result, this, [this](KJob * job) {
@@ -120,7 +123,7 @@ private Q_SLOTS:
         }
 #endif
         QVERIFY(QFileInfo(m_srcFile).isWritable());
-        m_mimeData.setUrls(QList<QUrl>() << QUrl::fromLocalFile(m_srcFile));
+        m_mimeData.setUrls(QList<QUrl>{QUrl::fromLocalFile(m_srcFile)});
     }
 
     void shouldDropToDesktopFile()
@@ -145,7 +148,7 @@ private Q_SLOTS:
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
-        QSignalSpy spy(job, SIGNAL(itemCreated(QUrl)));
+        QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
         // Then the application is run with the source file as argument
         // (in this example, it copies the source file to "dest")
@@ -199,14 +202,14 @@ private Q_SLOTS:
 
         // When dropping the source file onto the directory
         const QUrl destUrl = QUrl::fromLocalFile(dest);
-        m_mimeData.setUrls(QList<QUrl>() << QUrl::fromLocalFile(srcFile));
+        m_mimeData.setUrls(QList<QUrl>{QUrl::fromLocalFile(srcFile)});
         QDropEvent dropEvent(QPoint(10, 10), dropAction, &m_mimeData, Qt::LeftButton, modifiers);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo | KIO::NoPrivilegeExecution);
         job->setUiDelegate(nullptr);
         job->setUiDelegateExtension(nullptr);
         JobSpy jobSpy(job);
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
-        QSignalSpy itemCreatedSpy(job, SIGNAL(itemCreated(QUrl)));
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
+        QSignalSpy itemCreatedSpy(job, &KIO::DropJob::itemCreated);
 
         // Then the file is copied
         QVERIFY(jobSpy.waitForResult());
@@ -251,21 +254,21 @@ private Q_SLOTS:
         const bool isLink = QFileInfo(srcFile).isSymLink();
 
         // When dropping it into the trash, with <modifiers> pressed
-        m_mimeData.setUrls(QList<QUrl>() << QUrl::fromLocalFile(srcFile));
+        m_mimeData.setUrls(QList<QUrl>{QUrl::fromLocalFile(srcFile)});
         QDropEvent dropEvent(QPoint(10, 10), dropAction, &m_mimeData, Qt::LeftButton, modifiers);
         KIO::DropJob *job = KIO::drop(&dropEvent, QUrl(QStringLiteral("trash:/")), KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
-        QSignalSpy itemCreatedSpy(job, SIGNAL(itemCreated(QUrl)));
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
+        QSignalSpy itemCreatedSpy(job, &KIO::DropJob::itemCreated);
 
         // Then a confirmation dialog should appear
-        PredefinedAnswerJobUiDelegate extension;
-        extension.m_deleteResult = true;
-        job->setUiDelegateExtension(&extension);
+        auto *uiDelegate = new KJobUiDelegate;
+        job->setUiDelegate(uiDelegate);
+        auto *askUserHandler = new MockAskUserInterface(uiDelegate);
+        askUserHandler->m_deleteResult = true;
 
-        // and the file should be moved to the trash, no matter what the modifiers are
+        // And the file should be moved to the trash, no matter what the modifiers are
         QVERIFY2(job->exec(), qPrintable(job->errorString()));
-        QCOMPARE(extension.m_askDeleteCalled, 1);
+        QCOMPARE(askUserHandler->m_askUserDeleteCalled, 1);
         QCOMPARE(copyJobSpy.count(), 1);
         QCOMPARE(itemCreatedSpy.count(), 1);
         const QUrl trashUrl = itemCreatedSpy.at(0).at(0).value<QUrl>();
@@ -287,19 +290,19 @@ private Q_SLOTS:
         const QFile::Permissions origPerms = QFileInfo(m_srcFile).permissions();
         QVERIFY(QFileInfo(m_srcFile).isWritable());
         KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(m_srcFile), QUrl(QStringLiteral("trash:/")));
-        QSignalSpy copyingDoneSpy(copyJob, SIGNAL(copyingDone(KIO::Job*,QUrl,QUrl,QDateTime,bool,bool)));
+        QSignalSpy copyingDoneSpy(copyJob, &KIO::CopyJob::copyingDone);
         QVERIFY(copyJob->exec());
         const QUrl trashUrl = copyingDoneSpy.at(0).at(2).value<QUrl>();
         QVERIFY(trashUrl.isValid());
         QVERIFY(!QFile::exists(m_srcFile));
 
         // When dropping the trashed file into a local dir, without modifiers
-        m_mimeData.setUrls(QList<QUrl>() << trashUrl);
+        m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, QUrl::fromLocalFile(m_srcDir), KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
-        QSignalSpy spy(job, SIGNAL(itemCreated(QUrl)));
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
+        QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
         // Then the file should be moved, without a popup. No point in copying out of the trash, or linking to it.
         QVERIFY2(job->exec(), qPrintable(job->errorString()));
@@ -326,11 +329,11 @@ private Q_SLOTS:
         const QUrl destUrl = QUrl::fromLocalFile(tempDestDir.path());
 
         // When dropping a link / icon of the trash...
-        m_mimeData.setUrls(QList<QUrl>() << trashUrl);
+        m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
         // Then a full move shouldn't happen, just a link
@@ -352,12 +355,12 @@ private Q_SLOTS:
         QVERIFY(!QFile::exists(m_srcFile));
 
         // When dropping the trashed file in the trash
-        m_mimeData.setUrls(QList<QUrl>() << trashUrl);
+        m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, QUrl(QStringLiteral("trash:/")), KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
-        QSignalSpy spy(job, SIGNAL(itemCreated(QUrl)));
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
+        QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
         // Then an error should be reported and no files action should occur
         QVERIFY(!job->exec());
@@ -408,8 +411,8 @@ private Q_SLOTS:
         job->setUiDelegateExtension(nullptr); // no rename dialog
         JobSpy jobSpy(job);
         qRegisterMetaType<KFileItemListProperties>();
-        QSignalSpy spyShow(job, SIGNAL(popupMenuAboutToShow(KFileItemListProperties)));
-        QSignalSpy copyJobSpy(job, SIGNAL(copyJobStarted(KIO::CopyJob*)));
+        QSignalSpy spyShow(job, &KIO::DropJob::popupMenuAboutToShow);
+        QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QVERIFY(spyShow.isValid());
 
         // Then a popup should appear, with the expected available actions
