@@ -1,22 +1,10 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright 2000       Stephan Kulow <coolo@kde.org>
-    Copyright 2000-2006  David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2006 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_DELETEJOB_H
@@ -48,7 +36,7 @@ class KIOCORE_EXPORT DeleteJob : public Job
     Q_OBJECT
 
 public:
-    ~DeleteJob() Q_DECL_OVERRIDE;
+    ~DeleteJob() override;
 
     /**
      * Returns the list of URLs.
@@ -65,7 +53,7 @@ Q_SIGNALS:
      */
     void totalFiles(KJob *job, unsigned long files);
     /**
-    * Emitted when the toal number of direcotries is known.
+    * Emitted when the total number of directories is known.
      * @param job the job that emitted this signal
      * @param dirs the total number of directories
      */
@@ -93,7 +81,7 @@ Q_SIGNALS:
     void deleting(KIO::Job *job, const QUrl &file);
 
 protected Q_SLOTS:
-    void slotResult(KJob *job) Q_DECL_OVERRIDE;
+    void slotResult(KJob *job) override;
 
 protected:
     DeleteJob(DeleteJobPrivate &dd);
