@@ -1,24 +1,12 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
-                       Waldo Bastian <bastian@kde.org>
-    Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
-    Copyright (C) 2013 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
+    SPDX-FileCopyrightText: 2013 Dawit Alemayehu <adawit@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_JOB_P_H
@@ -27,7 +15,7 @@
 #include "simplejob.h"
 #include "transferjob.h"
 #include "commands_p.h"
-#include "kjobtrackerinterface.h"
+#include <KJobTrackerInterface>
 #include <kio/jobuidelegateextension.h>
 #include <kio/jobuidelegatefactory.h>
 #include <QUrl>
@@ -63,7 +51,7 @@ public:
            EF_TransferJobNeedData = (1 << 1),
            EF_TransferJobDataSent = (1 << 2),
            EF_ListJobUnrestricted = (1 << 3),
-           EF_KillCalled          = (1 << 4)
+           EF_KillCalled          = (1 << 4),
          };
 
     enum FileOperationType {
@@ -75,7 +63,7 @@ public:
         Rename,
         Symlink,
         Transfer, // put() and get()
-        Other // if other file operation set message, caption inside the job.
+        Other, // if other file operation set message, caption inside the job.
     };
 
     // Maybe we could use the QObject parent/child mechanism instead
@@ -120,15 +108,6 @@ public:
         : m_slave(nullptr), m_packedArgs(packedArgs), m_url(url), m_command(command),
           m_checkOnHold(false), m_schedSerial(0), m_redirectionHandlingEnabled(true)
     {
-#if 0
-        if (m_url.hasSubUrl()) {
-            QList<QUrl> list = KUrl::split(m_url);
-            list.removeLast();
-            m_subUrl = KUrl::join(list);
-            //qDebug() << "New URL = "  << m_url.url();
-            //qDebug() << "Sub URL = "  << m_subUrl.url();
-        }
-#endif
     }
 
     Slave *m_slave;
@@ -300,6 +279,7 @@ public:
     bool m_closedBeforeStart;
     TransferJob *m_subJob;
     QPointer<QIODevice> m_outgoingDataSource;
+    QMetaObject::Connection m_readChannelFinishedConnection;
 
     /**
      * Flow control. Suspend data processing from the slave.
