@@ -1,37 +1,27 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2007, 2008 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007, 2008 Andreas Hartmetz <ahartmetz@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ktcpsocket.h"
-#include "ktcpsocket_p.h"
+#include "ksslerror_p.h"
 #include "kiocoredebug.h"
 
 #include <ksslcertificatemanager.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
+#include <QAbstractSocket>
 #include <QUrl>
 #include <QSslKey>
 #include <QSslCipher>
 #include <QHostAddress>
 #include <QNetworkProxy>
-#include <QNetworkReply>
 #include <QAuthenticator>
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 65)
+
 static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
 {
     switch (protocol) {
@@ -45,10 +35,8 @@ static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
         return KTcpSocket::TlsV1_1;
     case QSsl::TlsV1_2:
         return KTcpSocket::TlsV1_2;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
     case QSsl::TlsV1_3:
         return KTcpSocket::TlsV1_3;
-#endif
     case QSsl::AnyProtocol:
         return KTcpSocket::AnySslVersion;
     case QSsl::TlsV1SslV3:
@@ -70,9 +58,7 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
     KTcpSocket::SslVersions validVersions(KTcpSocket::SslV2 | KTcpSocket::SslV3 | KTcpSocket::TlsV1);
     validVersions |= KTcpSocket::TlsV1_1;
     validVersions |= KTcpSocket::TlsV1_2;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
     validVersions |= KTcpSocket::TlsV1_3;
-#endif
     validVersions |= KTcpSocket::TlsV1SslV3;
     validVersions |= KTcpSocket::SecureProtocols;
 
@@ -91,10 +77,8 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
         return QSsl::TlsV1_1;
     case KTcpSocket::TlsV1_2:
         return QSsl::TlsV1_2;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
     case KTcpSocket::TlsV1_3:
         return QSsl::TlsV1_3;
-#endif
     case KTcpSocket::TlsV1SslV3:
         return QSsl::TlsV1SslV3;
     case KTcpSocket::SecureProtocols:
@@ -119,10 +103,8 @@ static QString protocolString(QSsl::SslProtocol protocol)
         return QStringLiteral("TLSv1.1");
     case QSsl::TlsV1_2:
         return QStringLiteral("TLSv1.2");
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
     case QSsl::TlsV1_3:
         return QStringLiteral("TLSv1.3");
-#endif
     default:
         return QStringLiteral("Unknown");;
     }
@@ -134,7 +116,8 @@ class CipherCc
 public:
     CipherCc()
     {
-        foreach (const QSslCipher &c, QSslConfiguration::supportedCiphers()) {
+        const QList<QSslCipher> list = QSslConfiguration::supportedCiphers();
+        for (const QSslCipher &c : list) {
             allCiphers.insert(c.name(), c);
         }
     }
@@ -148,106 +131,98 @@ private:
     QHash<QString, QSslCipher> allCiphers;
 };
 
-class KSslErrorPrivate
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 65)
+KSslError::Error KSslErrorPrivate::errorFromQSslError(QSslError::SslError e)
 {
-public:
-    static KSslError::Error errorFromQSslError(QSslError::SslError e)
-    {
-        switch (e) {
-        case QSslError::NoError:
-            return KSslError::NoError;
-        case QSslError::UnableToGetLocalIssuerCertificate:
-        case QSslError::InvalidCaCertificate:
-            return KSslError::InvalidCertificateAuthorityCertificate;
-        case QSslError::InvalidNotBeforeField:
-        case QSslError::InvalidNotAfterField:
-        case QSslError::CertificateNotYetValid:
-        case QSslError::CertificateExpired:
-            return KSslError::ExpiredCertificate;
-        case QSslError::UnableToDecodeIssuerPublicKey:
-        case QSslError::SubjectIssuerMismatch:
-        case QSslError::AuthorityIssuerSerialNumberMismatch:
-            return KSslError::InvalidCertificate;
-        case QSslError::SelfSignedCertificate:
-        case QSslError::SelfSignedCertificateInChain:
-            return KSslError::SelfSignedCertificate;
-        case QSslError::CertificateRevoked:
-            return KSslError::RevokedCertificate;
-        case QSslError::InvalidPurpose:
-            return KSslError::InvalidCertificatePurpose;
-        case QSslError::CertificateUntrusted:
-            return KSslError::UntrustedCertificate;
-        case QSslError::CertificateRejected:
-            return KSslError::RejectedCertificate;
-        case QSslError::NoPeerCertificate:
-            return KSslError::NoPeerCertificate;
-        case QSslError::HostNameMismatch:
-            return KSslError::HostNameMismatch;
-        case QSslError::UnableToVerifyFirstCertificate:
-        case QSslError::UnableToDecryptCertificateSignature:
-        case QSslError::UnableToGetIssuerCertificate:
-        case QSslError::CertificateSignatureFailed:
-            return KSslError::CertificateSignatureFailed;
-        case QSslError::PathLengthExceeded:
-            return KSslError::PathLengthExceeded;
-        case QSslError::UnspecifiedError:
-        case QSslError::NoSslSupport:
-        default:
-            return KSslError::UnknownError;
-        }
+    switch (e) {
+    case QSslError::NoError:
+        return KSslError::NoError;
+    case QSslError::UnableToGetLocalIssuerCertificate:
+    case QSslError::InvalidCaCertificate:
+        return KSslError::InvalidCertificateAuthorityCertificate;
+    case QSslError::InvalidNotBeforeField:
+    case QSslError::InvalidNotAfterField:
+    case QSslError::CertificateNotYetValid:
+    case QSslError::CertificateExpired:
+        return KSslError::ExpiredCertificate;
+    case QSslError::UnableToDecodeIssuerPublicKey:
+    case QSslError::SubjectIssuerMismatch:
+    case QSslError::AuthorityIssuerSerialNumberMismatch:
+        return KSslError::InvalidCertificate;
+    case QSslError::SelfSignedCertificate:
+    case QSslError::SelfSignedCertificateInChain:
+        return KSslError::SelfSignedCertificate;
+    case QSslError::CertificateRevoked:
+        return KSslError::RevokedCertificate;
+    case QSslError::InvalidPurpose:
+        return KSslError::InvalidCertificatePurpose;
+    case QSslError::CertificateUntrusted:
+        return KSslError::UntrustedCertificate;
+    case QSslError::CertificateRejected:
+        return KSslError::RejectedCertificate;
+    case QSslError::NoPeerCertificate:
+        return KSslError::NoPeerCertificate;
+    case QSslError::HostNameMismatch:
+        return KSslError::HostNameMismatch;
+    case QSslError::UnableToVerifyFirstCertificate:
+    case QSslError::UnableToDecryptCertificateSignature:
+    case QSslError::UnableToGetIssuerCertificate:
+    case QSslError::CertificateSignatureFailed:
+        return KSslError::CertificateSignatureFailed;
+    case QSslError::PathLengthExceeded:
+        return KSslError::PathLengthExceeded;
+    case QSslError::UnspecifiedError:
+    case QSslError::NoSslSupport:
+    default:
+        return KSslError::UnknownError;
     }
+}
 
-    static QString errorString(KSslError::Error e)
-    {
-        switch (e) {
+QSslError::SslError KSslErrorPrivate::errorFromKSslError(KSslError::Error e)
+{
+    switch (e) {
         case KSslError::NoError:
-            return i18nc("SSL error", "No error");
+            return QSslError::NoError;
         case KSslError::InvalidCertificateAuthorityCertificate:
-            return i18nc("SSL error", "The certificate authority's certificate is invalid");
-        case KSslError::ExpiredCertificate:
-            return i18nc("SSL error", "The certificate has expired");
+            return QSslError::InvalidCaCertificate;
         case KSslError::InvalidCertificate:
-            return i18nc("SSL error", "The certificate is invalid");
-        case KSslError::SelfSignedCertificate:
-            return i18nc("SSL error", "The certificate is not signed by any trusted certificate authority");
-        case KSslError::RevokedCertificate:
-            return i18nc("SSL error", "The certificate has been revoked");
-        case KSslError::InvalidCertificatePurpose:
-            return i18nc("SSL error", "The certificate is unsuitable for this purpose");
-        case KSslError::UntrustedCertificate:
-            return i18nc("SSL error", "The root certificate authority's certificate is not trusted for this purpose");
-        case KSslError::RejectedCertificate:
-            return i18nc("SSL error", "The certificate authority's certificate is marked to reject this certificate's purpose");
-        case KSslError::NoPeerCertificate:
-            return i18nc("SSL error", "The peer did not present any certificate");
-        case KSslError::HostNameMismatch:
-            return i18nc("SSL error", "The certificate does not apply to the given host");
+            return QSslError::UnableToDecodeIssuerPublicKey;
         case KSslError::CertificateSignatureFailed:
-            return i18nc("SSL error", "The certificate cannot be verified for internal reasons");
+            return QSslError::CertificateSignatureFailed;
+        case KSslError::SelfSignedCertificate:
+            return QSslError::SelfSignedCertificate;
+        case KSslError::ExpiredCertificate:
+            return QSslError::CertificateExpired;
+        case KSslError::RevokedCertificate:
+            return QSslError::CertificateRevoked;
+        case KSslError::InvalidCertificatePurpose:
+            return QSslError::InvalidPurpose;
+        case KSslError::RejectedCertificate:
+            return QSslError::CertificateRejected;
+        case KSslError::UntrustedCertificate:
+            return QSslError::CertificateUntrusted;
+        case KSslError::NoPeerCertificate:
+            return QSslError::NoPeerCertificate;
+        case KSslError::HostNameMismatch:
+            return QSslError::HostNameMismatch;
         case KSslError::PathLengthExceeded:
-            return i18nc("SSL error", "The certificate chain is too long");
+            return QSslError::PathLengthExceeded;
         case KSslError::UnknownError:
         default:
-            return i18nc("SSL error", "Unknown error");
-        }
+            return QSslError::UnspecifiedError;
     }
-
-    KSslError::Error error;
-    QSslCertificate certificate;
-};
+}
 
 KSslError::KSslError(Error errorCode, const QSslCertificate &certificate)
     : d(new KSslErrorPrivate())
 {
-    d->error = errorCode;
-    d->certificate = certificate;
+    d->error = QSslError(d->errorFromKSslError(errorCode), certificate);
 }
 
 KSslError::KSslError(const QSslError &other)
     : d(new KSslErrorPrivate())
 {
-    d->error = KSslErrorPrivate::errorFromQSslError(other.error());
-    d->certificate = other.certificate();
+    d->error = other;
 }
 
 KSslError::KSslError(const KSslError &other)
@@ -269,19 +244,25 @@ KSslError &KSslError::operator=(const KSslError &other)
 
 KSslError::Error KSslError::error() const
 {
-    return d->error;
+    return KSslErrorPrivate::errorFromQSslError(d->error.error());
 }
 
 QString KSslError::errorString() const
 {
-    return KSslErrorPrivate::errorString(d->error);
+    return d->error.errorString();
 }
 
 QSslCertificate KSslError::certificate() const
 {
-    return d->certificate;
+    return d->error.certificate();
 }
 
+QSslError KSslError::sslError() const
+{
+    return d->error;
+}
+#endif
+
 class KTcpSocketPrivate
 {
 public:
@@ -365,7 +346,7 @@ public:
     void reemitSocketError(QAbstractSocket::SocketError e)
     {
         q->setErrorString(sock.errorString());
-        emit q->error(errorFromAbsSocket(e));
+        Q_EMIT q->error(errorFromAbsSocket(e));
     }
 
     void reemitSslErrors(const QList<QSslError> &errors)
@@ -377,17 +358,17 @@ public:
         for (const QSslError &e : errors) {
             kErrors.append(KSslError(e));
         }
-        emit q->sslErrors(kErrors);
+        Q_EMIT q->sslErrors(kErrors);
     }
 
     void reemitStateChanged(QAbstractSocket::SocketState s)
     {
-        emit q->stateChanged(state(s));
+        Q_EMIT q->stateChanged(state(s));
     }
 
     void reemitModeChanged(QSslSocket::SslMode m)
     {
-        emit q->encryptionModeChanged(encryptionMode(m));
+        Q_EMIT q->encryptionModeChanged(encryptionMode(m));
     }
 
     // This method is needed because we might emit readyRead() due to this QIODevice
@@ -397,7 +378,7 @@ public:
     {
         if (!emittedReadyRead) {
             emittedReadyRead = true;
-            emit q->readyRead();
+            Q_EMIT q->readyRead();
             emittedReadyRead = false;
         }
     }
@@ -427,7 +408,7 @@ KTcpSocket::KTcpSocket(QObject *parent)
     connect(&d->sock, &QIODevice::aboutToClose, this, &QIODevice::aboutToClose);
     connect(&d->sock, &QIODevice::bytesWritten, this, &QIODevice::bytesWritten);
     connect(&d->sock, &QSslSocket::encryptedBytesWritten, this, &KTcpSocket::encryptedBytesWritten);
-    connect(&d->sock, SIGNAL(readyRead()), this, SLOT(reemitReadyRead()));
+    connect(&d->sock, &QSslSocket::readyRead, this, [this]() { d->reemitReadyRead(); });
     connect(&d->sock, &QAbstractSocket::connected, this, &KTcpSocket::connected);
     connect(&d->sock, &QSslSocket::encrypted, this, &KTcpSocket::encrypted);
     connect(&d->sock, &QAbstractSocket::disconnected, this, &KTcpSocket::disconnected);
@@ -435,15 +416,22 @@ KTcpSocket::KTcpSocket(QObject *parent)
     connect(&d->sock, &QAbstractSocket::proxyAuthenticationRequired,
             this, &KTcpSocket::proxyAuthenticationRequired);
 #endif
-    connect(&d->sock, SIGNAL(error(QAbstractSocket::SocketError)),
-            this, SLOT(reemitSocketError(QAbstractSocket::SocketError)));
-    connect(&d->sock, SIGNAL(sslErrors(QList<QSslError>)),
-            this, SLOT(reemitSslErrors(QList<QSslError>)));
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    connect(&d->sock, QOverload<QAbstractSocket::SocketError>::of(&QSslSocket::error),
+            this, [this](QAbstractSocket::SocketError err) { d->reemitSocketError(err); });
+#else
+    connect(&d->sock, &QSslSocket::errorOccurred,
+            this, [this](QAbstractSocket::SocketError err) { d->reemitSocketError(err); });
+#endif
+
+    connect(&d->sock, QOverload<const QList<QSslError> &>::of(&QSslSocket::sslErrors),
+            this, [this](const QList<QSslError> &errorList) { d->reemitSslErrors(errorList); });
     connect(&d->sock, &QAbstractSocket::hostFound, this, &KTcpSocket::hostFound);
-    connect(&d->sock, SIGNAL(stateChanged(QAbstractSocket::SocketState)),
-            this, SLOT(reemitStateChanged(QAbstractSocket::SocketState)));
-    connect(&d->sock, SIGNAL(modeChanged(QSslSocket::SslMode)),
-            this, SLOT(reemitModeChanged(QSslSocket::SslMode)));
+    connect(&d->sock, &QSslSocket::stateChanged,
+            this, [this](QAbstractSocket::SocketState state) { d->reemitStateChanged(state); });
+    connect(&d->sock, &QSslSocket::modeChanged,
+            this, [this](QSslSocket::SslMode mode) { d->reemitModeChanged(mode); });
 }
 
 KTcpSocket::~KTcpSocket()
@@ -559,7 +547,8 @@ void KTcpSocket::disconnectFromHost()
 
 KTcpSocket::Error KTcpSocket::error() const
 {
-    return d->errorFromAbsSocket(d->sock.error());
+    const auto networkError = d->sock.error();
+    return d->errorFromAbsSocket(networkError);
 }
 
 QList<KSslError> KTcpSocket::sslErrors() const
@@ -567,7 +556,11 @@ QList<KSslError> KTcpSocket::sslErrors() const
     //### pretty slow; also consider throwing out duplicate error codes. We may get
     //    duplicates even though there were none in the original list because KSslError
     //    has a smallest common denominator range of SSL error codes.
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    const auto qsslErrors = d->sock.sslHandshakeErrors();
+#else
     const auto qsslErrors = d->sock.sslErrors();
+#endif
     QList<KSslError> ret;
     ret.reserve(qsslErrors.size());
     for (const QSslError &e : qsslErrors) {
@@ -660,7 +653,11 @@ bool KTcpSocket::waitForDisconnected(int msecs)
 void KTcpSocket::addCaCertificate(const QSslCertificate &certificate)
 {
     d->maybeLoadCertificates();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     d->sock.addCaCertificate(certificate);
+#else
+    d->sock.sslConfiguration().addCaCertificate(certificate);
+#endif
 }
 
 /*
@@ -675,7 +672,11 @@ bool KTcpSocket::addCaCertificates(const QString &path, QSsl::EncodingFormat for
 void KTcpSocket::addCaCertificates(const QList<QSslCertificate> &certificates)
 {
     d->maybeLoadCertificates();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     d->sock.addCaCertificates(certificates);
+#else
+    d->sock.sslConfiguration().addCaCertificates(certificates);
+#endif
 }
 
 QList<QSslCertificate> KTcpSocket::caCertificates() const
@@ -730,7 +731,7 @@ void KTcpSocket::setCiphers(const QList<KSslCipher> &ciphers)
     d->ciphers = ciphers;
     QList<QSslCipher> cl;
     cl.reserve(d->ciphers.size());
-    foreach (const KSslCipher &c, d->ciphers) {
+    for (const KSslCipher &c : ciphers) {
         cl.append(d->ccc.converted(c));
     }
     QSslConfiguration configuration = d->sock.sslConfiguration();
@@ -829,7 +830,12 @@ void KTcpSocket::startClientEncryption()
 //debugging H4X
 void KTcpSocket::showSslErrors()
 {
-    foreach (const QSslError &e, d->sock.sslErrors()) {
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    const QList<QSslError> list = d->sock.sslErrors();
+#else
+    const QList<QSslError> list = d->sock.sslHandshakeErrors();
+#endif
+    for (const QSslError &e : list) {
         qCDebug(KIO_CORE) << e.errorString();
     }
 }
@@ -1056,79 +1062,6 @@ QList<KSslCipher> KSslCipher::supportedCiphers()
     return ret;
 }
 
-KSslErrorUiData::KSslErrorUiData()
-    : d(new Private())
-{
-    d->usedBits = 0;
-    d->bits = 0;
-}
-
-KSslErrorUiData::KSslErrorUiData(const KTcpSocket *socket)
-    : d(new Private())
-{
-    d->certificateChain = socket->peerCertificateChain();
-    d->sslErrors = socket->sslErrors();
-    d->ip = socket->peerAddress().toString();
-    d->host = socket->peerName();
-    d->sslProtocol = socket->negotiatedSslVersionName();
-    d->cipher = socket->sessionCipher().name();
-    d->usedBits = socket->sessionCipher().usedBits();
-    d->bits = socket->sessionCipher().supportedBits();
-}
-
-KSslErrorUiData::KSslErrorUiData(const QSslSocket *socket)
-    : d(new Private())
-{
-    d->certificateChain = socket->peerCertificateChain();
-
-    // See KTcpSocket::sslErrors()
-    const auto qsslErrors = socket->sslErrors();
-    d->sslErrors.reserve(qsslErrors.size());
-    for (const QSslError &e : qsslErrors) {
-        d->sslErrors.append(KSslError(e));
-    }
-
-    d->ip = socket->peerAddress().toString();
-    d->host = socket->peerName();
-    if (socket->isEncrypted()) {
-        d->sslProtocol = socket->sessionCipher().protocolString();
-    }
-    d->cipher = socket->sessionCipher().name();
-    d->usedBits = socket->sessionCipher().usedBits();
-    d->bits = socket->sessionCipher().supportedBits();
-}
-
-KSslErrorUiData::KSslErrorUiData(const QNetworkReply *reply, const QList<QSslError> &sslErrors)
-    : d(new Private())
-{
-    const auto sslConfig = reply->sslConfiguration();
-    d->certificateChain = sslConfig.peerCertificateChain();
-
-    d->sslErrors.reserve(sslErrors.size());
-    for (const QSslError &e : sslErrors) {
-        d->sslErrors.append(KSslError(e));
-    }
-
-    d->host = reply->request().url().host();
-    d->sslProtocol = sslConfig.sessionCipher().protocolString();
-    d->cipher = sslConfig.sessionCipher().name();
-    d->usedBits = sslConfig.sessionCipher().usedBits();
-    d->bits = sslConfig.sessionCipher().supportedBits();
-}
-
-KSslErrorUiData::KSslErrorUiData(const KSslErrorUiData &other)
-    : d(new Private(*other.d))
-{}
-
-KSslErrorUiData::~KSslErrorUiData()
-{
-    delete d;
-}
-
-KSslErrorUiData &KSslErrorUiData::operator=(const KSslErrorUiData &other)
-{
-    *d = *other.d;
-    return *this;
-}
-
 #include "moc_ktcpsocket.cpp"
+
+#endif
