@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "listjob.h"
@@ -24,6 +12,7 @@
 #include <kurlauthorized.h>
 #include "slave.h"
 #include "../pathhelpers_p.h"
+#include <QTimer>
 
 #include <QDebug>
 
@@ -52,7 +41,7 @@ public:
      * work on this job.
      * @param slave the slave that starts working on this job
      */
-    void start(Slave *slave) Q_DECL_OVERRIDE;
+    void start(Slave *slave) override;
 
     void slotListEntries(const KIO::UDSEntryList &list);
     void slotRedirection(const QUrl &url);
@@ -129,11 +118,11 @@ void ListJobPrivate::slotListEntries(const KIO::UDSEntryList &list)
                     displayName = filename;
                 }
                 // skip hidden dirs when listing if requested
-                if (filename != QLatin1String("..") && filename != QLatin1String(".") && (includeHidden || filename[0] != '.')) {
+                if (filename != QLatin1String("..") && filename != QLatin1String(".") && (includeHidden || filename[0] != QLatin1Char('.'))) {
                     ListJob *job = ListJobPrivate::newJobNoUi(itemURL,
                                    true /*recursive*/,
-                                   m_prefix + filename + '/',
-                                   m_displayPrefix + displayName + '/',
+                                   m_prefix + filename + QLatin1Char('/'),
+                                   m_displayPrefix + displayName + QLatin1Char('/'),
                                    includeHidden);
                     Scheduler::setJobPriority(job, 1);
                     QObject::connect(job, &ListJob::entries, q,
@@ -151,7 +140,7 @@ void ListJobPrivate::slotListEntries(const KIO::UDSEntryList &list)
     // exclusion of hidden files also requires the full sweep, but the case for full-listing
     // a single dir is probably common enough to justify the shortcut
     if (m_prefix.isNull() && includeHidden) {
-        emit q->entries(q, list);
+        Q_EMIT q->entries(q, list);
     } else {
         // cull the unwanted hidden dirs and/or parent dir references from the listing, then emit that
         UDSEntryList newlist;
@@ -170,15 +159,15 @@ void ListJobPrivate::slotListEntries(const KIO::UDSEntryList &list)
             // Avoid returning entries like subdir/. and subdir/.., but include . and .. for
             // the toplevel dir, and skip hidden files/dirs if that was requested
             if ((m_prefix.isNull() || (filename != QLatin1String("..") && filename != QLatin1String(".")))
-                    && (includeHidden || (filename[0] != '.'))) {
+                    && (includeHidden || (filename[0] != QLatin1Char('.')))) {
                 // ## Didn't find a way to use the iterator instead of re-doing a key lookup
-                newone.insert(KIO::UDSEntry::UDS_NAME, m_prefix + filename);
-                newone.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, m_displayPrefix + displayName);
+                newone.replace(KIO::UDSEntry::UDS_NAME, m_prefix + filename);
+                newone.replace(KIO::UDSEntry::UDS_DISPLAY_NAME, m_displayPrefix + displayName);
                 newlist.append(newone);
             }
         }
 
-        emit q->entries(q, newlist);
+        Q_EMIT q->entries(q, newlist);
     }
 }
 
@@ -186,13 +175,13 @@ void ListJobPrivate::gotEntries(KIO::Job *, const KIO::UDSEntryList &list)
 {
     // Forward entries received by subjob - faking we received them ourselves
     Q_Q(ListJob);
-    emit q->entries(q, list);
+    Q_EMIT q->entries(q, list);
 }
 
 void ListJobPrivate::slotSubError(KIO::ListJob* /*job*/, KIO::ListJob* subJob)
 {
     Q_Q(ListJob);
-    emit q->subError(q, subJob); // Let the signal of subError go up
+    Q_EMIT q->subError(q, subJob); // Let the signal of subError go up
 }
 
 void ListJob::slotResult(KJob *job)
@@ -203,7 +192,7 @@ void ListJob::slotResult(KJob *job)
         // This is why we override KCompositeJob::slotResult - to not set
         // an error on parent job.
         // Let's emit a signal about this though
-        emit subError(this, static_cast<KIO::ListJob *>(job));
+        Q_EMIT subError(this, static_cast<KIO::ListJob *>(job));
     }
     removeSubjob(job);
     if (!hasSubjobs() && !d->m_slave) { // if the main directory listing is still running, it will emit result in SimpleJob::slotFinished()
@@ -219,7 +208,7 @@ void ListJobPrivate::slotRedirection(const QUrl &url)
         return;
     }
     m_redirectionURL = url; // We'll remember that when the job finishes
-    emit q->redirection(q, m_redirectionURL);
+    Q_EMIT q->redirection(q, m_redirectionURL);
 }
 
 void ListJob::slotFinished()
@@ -230,7 +219,7 @@ void ListJob::slotFinished()
 
         //qDebug() << "Redirection to " << d->m_redirectionURL;
         if (queryMetaData(QStringLiteral("permanent-redirect")) == QLatin1String("true")) {
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
+            Q_EMIT permanentRedirection(this, d->m_url, d->m_redirectionURL);
         }
 
         if (d->m_redirectionHandlingEnabled) {
@@ -281,7 +270,7 @@ void ListJobPrivate::start(Slave *slave)
             !(m_extraFlags & EF_ListJobUnrestricted)) {
         q->setError(ERR_ACCESS_DENIED);
         q->setErrorText(m_url.toDisplayString());
-        QTimer::singleShot(0, q, SLOT(slotFinished()));
+        QTimer::singleShot(0, q, &ListJob::slotFinished);
         return;
     }
     QObject::connect(slave, &Slave::listEntries, q,
