@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2012 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2012 Dawit Alemayehu <adawit@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef USERNOTIFICATIONHANDLER_P_H
@@ -42,7 +31,7 @@ public:
         MSG_YES_BUTTON_ICON,
         MSG_NO_BUTTON_ICON,
         MSG_DONT_ASK_AGAIN,
-        MSG_META_DATA
+        MSG_META_DATA,
     };
 
     class Request
@@ -56,7 +45,7 @@ public:
         QHash<MessageBoxDataType, QVariant> data;
     };
 
-    UserNotificationHandler(QObject *parent = nullptr);
+    explicit UserNotificationHandler(QObject *parent = nullptr);
     virtual ~UserNotificationHandler();
 
     void requestMessageBox(SlaveInterface *iface, int type, const QHash<MessageBoxDataType, QVariant> &data);
