@@ -30,7 +30,7 @@ class KUrlNavigatorProtocolCombo : public KUrlNavigatorButtonBase
     Q_OBJECT
 
 public:
-    explicit KUrlNavigatorProtocolCombo(const QString &protocol, QWidget *parent = nullptr);
+    explicit KUrlNavigatorProtocolCombo(const QString &protocol, KUrlNavigator *parent = nullptr);
 
     QString currentProtocol() const;
 
@@ -49,7 +49,7 @@ protected:
     void paintEvent(QPaintEvent *event) override;
 
 private Q_SLOTS:
-    void setProtocol(QAction *action);
+    void setProtocolFromMenu(QAction *action);
 
 private:
     void updateMenu();
@@ -61,7 +61,7 @@ private:
         DevicesCategory,
         SubversionCategory,
         OtherCategory,
-        CategoryCount // mandatory last entry
+        CategoryCount, // mandatory last entry
     };
 
     QMenu *m_menu;
