@@ -1,28 +1,11 @@
 /*
-This file is part of KDE
+    This file is part of KDE
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000 Dawit Alemayehu <adawit@kde.org>
 
-  Copyright (C) 2000- Waldo Bastian <bastian@kde.org>
-  Copyright (C) 2000- Dawit Alemayehu <adawit@kde.org>
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
-//----------------------------------------------------------------------------
-//
+
 // KDE File Manager -- HTTP Cookie Dialogs
 
 // The purpose of the QT_NO_TOOLTIP and QT_NO_WHATSTHIS ifdefs is because
@@ -35,26 +18,23 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 // too much trouble... (Simon)
 
 #include "kcookiewin.h"
-#include "kcookiejar.h"
 
 #include <QDateTime>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLayout>
 #include <QLineEdit>
-#include <QGroupBox>
 #include <QPushButton>
-#include <QRadioButton>
 #include <QShortcut>
 #include <QStyle>
 #include <QUrl>
 
 #include <kwindowsystem.h>
-#include <klocalizedstring.h>
-#include <kusertimestamp.h>
+#include <KLocalizedString>
+#include <KUserTimestamp>
 
 enum {
-    AcceptedForSession = QDialog::Accepted + 1
+    AcceptedForSession = QDialog::Accepted + 1,
 };
 
 KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
@@ -99,11 +79,10 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
                   cookie.isCrossDomain() ? i18nc("@item:intext cross domain cookie", " [Cross Domain]") : QString());
     txt += QLatin1String("</body></html>");
 
-    QVBoxLayout *topLayout = new QVBoxLayout;
+    QVBoxLayout *topLayout = new QVBoxLayout(this);
     // This may look wrong, but it makes the dialogue automatically
     // shrink when the details are shown and then hidden again.
     topLayout->setSizeConstraint(QLayout::SetFixedSize);
-    setLayout(topLayout);
 
     QFrame *vBox1 = new QFrame(this);
     topLayout->addWidget(vBox1);
@@ -171,7 +150,7 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
     // Cookie policy choice...
     QGroupBox *m_btnGrp = new QGroupBox(i18n("Apply Choice To"), vBox1);
     vBox1Layout->addWidget(m_btnGrp);
-    QVBoxLayout *vbox = new QVBoxLayout;
+    QVBoxLayout *vbox = new QVBoxLayout(m_btnGrp);
     txt = (count == 1) ? i18n("&Only this cookie") : i18n("&Only these cookies");
     m_onlyCookies = new QRadioButton(txt, m_btnGrp);
     vbox->addWidget(m_onlyCookies);
@@ -195,7 +174,6 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
                                     "cookie policy for all cookies until you manually change "
                                     "it from the System Settings."));
 #endif
-    m_btnGrp->setLayout(vbox);
 
     switch (defaultButton) {
     case KCookieJar::ApplyToShownCookiesOnly:
@@ -345,8 +323,7 @@ void KCookieDetail::displayCookieDetails()
         m_domain->setText(cookie.domain());
     }
     m_path->setText(cookie.path());
-    QDateTime cookiedate;
-    cookiedate.setTime_t(cookie.expireDate());
+    QDateTime cookiedate = QDateTime::fromSecsSinceEpoch(cookie.expireDate());
     if (cookie.expireDate()) {
         m_expires->setText(cookiedate.toString());
     } else {
