@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TESTTRASH_H
@@ -59,29 +47,34 @@ private Q_SLOTS:
     void trashDirectoryFromOther();
     void trashDirectoryOwnedByRoot();
     void trashDirectoryWithTrailingSlash();
-
-    void tryRenameInsideTrash();
+    void trashBrokenSymlinkIntoSubdir();
 
     void statRoot();
     void statFileInRoot();
     void statDirectoryInRoot();
     void statSymlinkInRoot();
     void statFileInDirectory();
+    void statBrokenSymlinkInSubdir();
+    void testRemoveStaleInfofile();
 
     void copyFileFromTrash();
     void copyFileInDirectoryFromTrash();
     void copyDirectoryFromTrash();
     void copySymlinkFromTrash();
 
+    void renameFileInTrash();
+    void renameDirInTrash();
     void moveFileFromTrash();
     void moveFileFromTrashToDir_data();
     void moveFileFromTrashToDir();
     void moveFileInDirectoryFromTrash();
     void moveDirectoryFromTrash();
     void moveSymlinkFromTrash();
+    void testMoveNonExistingFile();
 
     void listRootDir();
     void listRecursiveRootDir();
+    void mostLocalUrlTest();
     void listSubDir();
 
     void delRootFile();
@@ -104,6 +97,7 @@ private:
     void trashSymlink(const QString &origFilePath, const QString &fileName, bool broken);
     void trashDirectory(const QString &origPath, const QString &fileName);
     void copyFromTrash(const QString &fileId, const QString &destPath, const QString &relativePath = QString());
+    void moveInTrash(const QString &fileId, const QString &destFileId);
     void moveFromTrash(const QString &fileId, const QString &destPath, const QString &relativePath = QString());
     void checkDirCacheValidity();
 
