@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "trashimpl.h"
@@ -23,24 +11,23 @@
 #include "kiotrashdebug.h"
 
 #include <KLocalizedString>
-#include <kio/job.h>
 #include <kio/chmodjob.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
-#include <qdebug.h>
+#include <QDebug>
 #include <QUrl>
 #include <kdirnotify.h>
 #include <KSharedConfig>
 #include <kfileitem.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <kmountpoint.h>
-#include <kfileutils.h>
+#include <KFileUtils>
 
 #include <QCoreApplication>
 #include <QEventLoop>
 #include <QFile>
 #include <QDir>
-#include <kjobuidelegate.h>
+#include <KJobUiDelegate>
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -93,10 +80,6 @@ int TrashImpl::testDir(const QString &_name) const
 
         bool ok = QDir().mkdir(name);
         if (!ok && QFile::exists(name)) {
-#if 0 // this would require to use SlaveBase's method to ask the question
-            //int ret = KMessageBox::warningYesNo( 0, i18n("%1 is a file, but KDE needs it to be a directory. Move it to %2.orig and create directory?").arg(name).arg(name) );
-            //if ( ret == KMessageBox::Yes ) {
-#endif
             QString new_name = name;
             name.append(QStringLiteral(".orig"));
             if (QFile::rename(name, new_name)) {
@@ -107,11 +90,6 @@ int TrashImpl::testDir(const QString &_name) const
             if (!ok) {
                 return KIO::ERR_DIR_ALREADY_EXIST;
             }
-#if 0
-            //} else {
-            //    return 0;
-            //}
-#endif
         }
         if (!ok) {
             //KMessageBox::sorry( 0, i18n( "Could not create directory %1. Check for permissions." ).arg( name ) );
@@ -479,7 +457,7 @@ void TrashImpl::jobFinished(KJob *job)
     //qCDebug(KIO_TRASH) << "error=" << job->error() << job->errorText();
     error(job->error(), job->errorText());
 
-    emit leaveModality();
+    Q_EMIT leaveModality();
 }
 
 bool TrashImpl::copyToTrash(const QString &origPath, int trashId, const QString &fileId)
@@ -545,6 +523,11 @@ bool TrashImpl::directRename(const QString &src, const QString &dest)
                 error(KIO::ERR_ACCESS_DENIED, dest);
             } else if (errno == EROFS) { // The file is on a read-only filesystem
                 error(KIO::ERR_CANNOT_DELETE, src);
+            } else if (errno == ENOENT) {
+                const QString marker(QStringLiteral("Trash/files/"));
+                const int idx = src.lastIndexOf(marker) + marker.size();
+                const QString displayName = QLatin1String("trash:/") + src.mid(idx);
+                error(KIO::ERR_DOES_NOT_EXIST, displayName);
             } else {
                 error(KIO::ERR_CANNOT_RENAME, src);
             }
@@ -754,20 +737,20 @@ TrashImpl::TrashedFileInfoList TrashImpl::list()
         //getcwd(path_buffer, PATH_MAX - 1);
         //if ( chdir( infoPathEnc ) )
         //    continue;
-        for (QStringList::const_iterator entryIt = entryNames.constBegin(), entryEnd = entryNames.constEnd();
-                entryIt != entryEnd; ++entryIt) {
-            QString fileName = *entryIt;
+
+        const QLatin1String tail(".trashinfo");
+        const int tailLength = tail.size();
+        for (const QString &fileName : entryNames) {
             if (fileName == QLatin1Char('.') || fileName == QLatin1String("..")) {
                 continue;
             }
-            if (!fileName.endsWith(QLatin1String(".trashinfo"))) {
+            if (!fileName.endsWith(tail)) {
                 qCWarning(KIO_TRASH) << "Invalid info file found in" << infoPath << ":" << fileName;
                 continue;
             }
-            fileName.chop(10);
 
             TrashedFileInfo info;
-            if (infoForFile(trashId, fileName, info)) {
+            if (infoForFile(trashId, fileName.chopped(tailLength), info)) {
                 lst << info;
             }
         }
@@ -1217,9 +1200,9 @@ QString TrashImpl::trashForMountPoint(const QString &topdir, bool createIfNeeded
     const QByteArray trashDir_c = QFile::encodeName(trashDir);
     if (QT_LSTAT(trashDir_c.constData(), &buff) == 0) {
         if ((buff.st_uid == uid)  // must be owned by user
-                && (S_ISDIR(buff.st_mode)) // must be a dir
-                && (!S_ISLNK(buff.st_mode)) // not a symlink
-                && ((buff.st_mode & 0777) == 0700)) {  // rwx for user, ------ for group and others
+                && S_ISDIR(buff.st_mode) // must be a dir
+                && !S_ISLNK(buff.st_mode) // not a symlink
+                && ((buff.st_mode & 0700) == 0700)) { // and we need write access to it
 
             if (checkTrashSubdirs(trashDir_c)) {
                 return trashDir;
@@ -1250,29 +1233,10 @@ int TrashImpl::idForTrashDirectory(const QString &trashDir) const
 
 bool TrashImpl::initTrashDirectory(const QByteArray &trashDir_c) const
 {
-    //qCDebug(KIO_TRASH) << trashDir_c;
     if (mkdir(trashDir_c.constData(), 0700) != 0) {
         return false;
     }
-    //qCDebug(KIO_TRASH);
-    // This trash dir will be useable only if the directory is owned by user.
-    // In theory this is the case, but not on e.g. USB keys...
-    uid_t uid = getuid();
-    QT_STATBUF buff;
-    if (QT_LSTAT(trashDir_c.constData(), &buff) != 0) {
-        return false;    // huh?
-    }
-    if ((buff.st_uid == uid)  // must be owned by user
-            && ((buff.st_mode & 0777) == 0700)) {  // rwx for user, --- for group and others
-
-        return checkTrashSubdirs(trashDir_c);
-
-    } else {
-        qCWarning(KIO_TRASH) << trashDir_c << "just created, by it doesn't have the right permissions, probably some strange unsupported filesystem";
-        ::rmdir(trashDir_c.constData());
-        return false;
-    }
-    return true;
+    return checkTrashSubdirs(trashDir_c);
 }
 
 bool TrashImpl::checkTrashSubdirs(const QByteArray &trashDir_c) const
