@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 2000 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2006, 2008 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2006, 2008 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fileundomanager.h"
@@ -29,21 +17,20 @@
 #include <kio/mkdirjob.h>
 #include <kio/mkpathjob.h>
 #include <kio/batchrenamejob.h>
-#include <kjobwidgets.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kjobtrackerinterface.h>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KJobTrackerInterface>
 #include <kio/jobuidelegate.h>
 #include <job_p.h>
 #include "kio_widgets_debug.h"
+#include "askuseractioninterface.h"
 
 #include <QDateTime>
 #include <QDBusConnection>
 #include <QFileInfo>
 #include <QLocale>
 
-#include <assert.h>
-
 using namespace KIO;
 
 static const char *undoStateToString(UndoState state)
@@ -71,14 +58,14 @@ static QDataStream &operator>>(QDataStream &stream, BasicOperation &op)
 
 static QDataStream &operator<<(QDataStream &stream, const UndoCommand &cmd)
 {
-    stream << cmd.m_valid << (qint8)cmd.m_type << cmd.m_opStack << cmd.m_src << cmd.m_dst;
+    stream << cmd.m_valid << (qint8)cmd.m_type << cmd.m_opQueue << cmd.m_src << cmd.m_dst;
     return stream;
 }
 
 static QDataStream &operator>>(QDataStream &stream, UndoCommand &cmd)
 {
     qint8 type;
-    stream >> cmd.m_valid >> type >> cmd.m_opStack >> cmd.m_src >> cmd.m_dst;
+    stream >> cmd.m_valid >> type >> cmd.m_opQueue >> cmd.m_src >> cmd.m_dst;
     cmd.m_type = static_cast<FileUndoManager::CommandType>(type);
     return stream;
 }
@@ -133,7 +120,7 @@ public:
     }
     ~UndoJob() override {}
 
-    virtual void kill(bool)
+    virtual void kill(bool) // TODO should be doKill
     {
         FileUndoManager::self()->d->stopUndo(true);
         KIO::Job::doKill();
@@ -141,18 +128,18 @@ public:
 
     void emitCreatingDir(const QUrl &dir)
     {
-        emit description(this, i18n("Creating directory"),
+        Q_EMIT description(this, i18n("Creating directory"),
                          qMakePair(i18n("Directory"), dir.toDisplayString()));
     }
     void emitMoving(const QUrl &src, const QUrl &dest)
     {
-        emit description(this, i18n("Moving"),
+        Q_EMIT description(this, i18n("Moving"),
                          qMakePair(i18nc("The source of a file operation", "Source"), src.toDisplayString()),
                          qMakePair(i18nc("The destination of a file operation", "Destination"), dest.toDisplayString()));
     }
     void emitDeleting(const QUrl &url)
     {
-        emit description(this, i18n("Deleting"),
+        Q_EMIT description(this, i18n("Deleting"),
                          qMakePair(i18n("File"), url.toDisplayString()));
     }
     void emitResult()
@@ -162,13 +149,9 @@ public:
 };
 
 CommandRecorder::CommandRecorder(FileUndoManager::CommandType op, const QList<QUrl> &src, const QUrl &dst, KIO::Job *job)
-    : QObject(job)
+    : QObject(job),
+      m_cmd(op, src, dst, FileUndoManager::self()->newCommandSerialNumber())
 {
-    m_cmd.m_type = op;
-    m_cmd.m_valid = true;
-    m_cmd.m_serialNumber = FileUndoManager::self()->newCommandSerialNumber();
-    m_cmd.m_src = src;
-    m_cmd.m_dst = dst;
     connect(job, &KJob::result,
             this, &CommandRecorder::slotResult);
     if (auto *copyJob = qobject_cast<KIO::CopyJob*>(job)) {
@@ -176,19 +159,15 @@ CommandRecorder::CommandRecorder(FileUndoManager::CommandType op, const QList<QU
                 this, &CommandRecorder::slotCopyingDone);
         connect(copyJob, &KIO::CopyJob::copyingLinkDone,
                 this, &CommandRecorder::slotCopyingLinkDone);
-    } else if (KIO::MkpathJob *mkpathJob = qobject_cast<KIO::MkpathJob *>(job)) {
+    } else if (auto *mkpathJob = qobject_cast<KIO::MkpathJob *>(job)) {
         connect(mkpathJob, &KIO::MkpathJob::directoryCreated,
                 this, &CommandRecorder::slotDirectoryCreated);
-    } else if (KIO::BatchRenameJob *batchRenameJob = qobject_cast<KIO::BatchRenameJob *>(job)) {
+    } else if (auto *batchRenameJob = qobject_cast<KIO::BatchRenameJob *>(job)) {
         connect(batchRenameJob, &KIO::BatchRenameJob::fileRenamed,
                 this, &CommandRecorder::slotBatchRenamingDone);
     }
 }
 
-CommandRecorder::~CommandRecorder()
-{
-}
-
 void CommandRecorder::slotResult(KJob *job)
 {
     if (job->error()) {
@@ -201,53 +180,23 @@ void CommandRecorder::slotResult(KJob *job)
 
 void CommandRecorder::slotCopyingDone(KIO::Job *, const QUrl &from, const QUrl &to, const QDateTime &mtime, bool directory, bool renamed)
 {
-    BasicOperation op;
-    op.m_valid = true;
-    op.m_type = directory ? BasicOperation::Directory : BasicOperation::File;
-    op.m_renamed = renamed;
-    op.m_src = from;
-    op.m_dst = to;
-    op.m_mtime = mtime;
-    //qDebug() << op;
-    m_cmd.m_opStack.prepend(op);
+    const BasicOperation::Type type = directory ? BasicOperation::Directory : BasicOperation::File;
+    m_cmd.m_opQueue.enqueue(BasicOperation(type, renamed, from, to, mtime));
 }
 
-// TODO merge the signals?
 void CommandRecorder::slotCopyingLinkDone(KIO::Job *, const QUrl &from, const QString &target, const QUrl &to)
 {
-    BasicOperation op;
-    op.m_valid = true;
-    op.m_type = BasicOperation::Link;
-    op.m_renamed = false;
-    op.m_src = from;
-    op.m_target = target;
-    op.m_dst = to;
-    op.m_mtime = QDateTime();
-    m_cmd.m_opStack.prepend(op);
+    m_cmd.m_opQueue.enqueue(BasicOperation(BasicOperation::Link, false, from, to, {}, target));
 }
 
 void CommandRecorder::slotDirectoryCreated(const QUrl &dir)
 {
-    BasicOperation op;
-    op.m_valid = true;
-    op.m_type = BasicOperation::Directory;
-    op.m_renamed = false;
-    op.m_src = QUrl();
-    op.m_dst = dir;
-    op.m_mtime = QDateTime();
-    m_cmd.m_opStack.prepend(op);
+    m_cmd.m_opQueue.enqueue(BasicOperation(BasicOperation::Directory, false, QUrl{}, dir, {}));
 }
 
 void CommandRecorder::slotBatchRenamingDone(const QUrl &from, const QUrl &to)
 {
-    BasicOperation op;
-    op.m_valid = true;
-    op.m_type = BasicOperation::Directory;
-    op.m_renamed = true;
-    op.m_src = from;
-    op.m_dst = to;
-    op.m_mtime = QDateTime();
-    m_cmd.m_opStack.prepend(op);
+    m_cmd.m_opQueue.enqueue(BasicOperation(BasicOperation::Directory, true, from, to, {}));
 }
 
 ////
@@ -270,7 +219,7 @@ FileUndoManager *FileUndoManager::self()
 // order of the undo items.
 FileUndoManagerPrivate::FileUndoManagerPrivate(FileUndoManager *qq)
     : m_uiInterface(new FileUndoManager::UiInterface()),
-      m_undoJob(nullptr), m_nextCommandIndex(1000), q(qq)
+      m_nextCommandIndex(1000), q(qq)
 {
     (void) new KIOFileUndoManagerAdaptor(this);
     const QString dbusPath = QStringLiteral("/FileUndoManager");
@@ -285,22 +234,19 @@ FileUndoManagerPrivate::FileUndoManagerPrivate(FileUndoManager *qq)
 }
 
 FileUndoManager::FileUndoManager()
+    : d(new FileUndoManagerPrivate(this))
 {
-    d = new FileUndoManagerPrivate(this);
-    d->m_lock = false;
-    d->m_currentJob = nullptr;
 }
 
 FileUndoManager::~FileUndoManager()
 {
-    delete d;
 }
 
 void FileUndoManager::recordJob(CommandType op, const QList<QUrl> &src, const QUrl &dst, KIO::Job *job)
 {
     // This records what the job does and calls addCommand when done
     (void) new CommandRecorder(op, src, dst, job);
-    emit jobRecordingStarted(op);
+    Q_EMIT jobRecordingStarted(op);
 }
 
 void FileUndoManager::recordCopyJob(KIO::CopyJob *copyJob)
@@ -314,9 +260,10 @@ void FileUndoManager::recordCopyJob(KIO::CopyJob *copyJob)
         commandType = Move;
         break;
     case CopyJob::Link:
-    default: // prevent "wrong" compiler warning because of possibly uninitialized variable
         commandType = Link;
         break;
+    default:
+        Q_UNREACHABLE();
     }
     recordJob(commandType, copyJob->srcUrls(), copyJob->destUrl(), copyJob);
 }
@@ -324,12 +271,19 @@ void FileUndoManager::recordCopyJob(KIO::CopyJob *copyJob)
 void FileUndoManagerPrivate::addCommand(const UndoCommand &cmd)
 {
     pushCommand(cmd);
-    emit q->jobRecordingFinished(cmd.m_type);
+    Q_EMIT q->jobRecordingFinished(cmd.m_type);
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 79)
 bool FileUndoManager::undoAvailable() const
 {
-    return (d->m_commands.count() > 0) && !d->m_lock;
+    return isUndoAvailable();
+}
+#endif
+
+bool FileUndoManager::isUndoAvailable() const
+{
+    return !d->m_commands.isEmpty() && !d->m_lock;
 }
 
 QString FileUndoManager::undoText() const
@@ -338,7 +292,7 @@ QString FileUndoManager::undoText() const
         return i18n("Und&o");
     }
 
-    FileUndoManager::CommandType t = d->m_commands.last().m_type;
+    FileUndoManager::CommandType t = d->m_commands.top().m_type;
     switch (t) {
     case FileUndoManager::Copy:
         return i18n("Und&o: Copy");
@@ -371,8 +325,8 @@ quint64 FileUndoManager::newCommandSerialNumber()
 quint64 FileUndoManager::currentCommandSerialNumber() const
 {
     if (!d->m_commands.isEmpty()) {
-        const UndoCommand &cmd = d->m_commands.last();
-        assert(cmd.m_valid);
+        const UndoCommand &cmd = d->m_commands.top();
+        Q_ASSERT(cmd.m_valid);
         return cmd.m_serialNumber;
     } else {
         return 0;
@@ -385,20 +339,19 @@ void FileUndoManager::undo()
 
     // Make a copy of the command to undo before slotPop() pops it.
     UndoCommand cmd = d->m_commands.last();
-    assert(cmd.m_valid);
+    Q_ASSERT(cmd.m_valid);
     d->m_current = cmd;
     const CommandType commandType = cmd.m_type;
 
-    BasicOperation::Stack &opStack = d->m_current.m_opStack;
-    // Note that opStack is empty for simple operations like Mkdir.
+    // Note that m_opQueue is empty for simple operations like Mkdir.
+    const auto &opQueue = d->m_current.m_opQueue;
 
     // Let's first ask for confirmation if we need to delete any file (#99898)
     QList<QUrl> itemsToDelete;
-    BasicOperation::Stack::Iterator it = opStack.begin();
-    for (; it != opStack.end(); ++it) {
-        BasicOperation::Type type = (*it).m_type;
-        const auto destination = (*it).m_dst;
-        if (type == BasicOperation::File && commandType == FileUndoManager::Copy) {
+    for (auto it = opQueue.crbegin(); it != opQueue.crend(); ++it) {
+        const BasicOperation &op = *it;
+        const auto destination = op.m_dst;
+        if (op.m_type == BasicOperation::File && commandType == FileUndoManager::Copy) {
             if (destination.isLocalFile() && !QFileInfo::exists(destination.toLocalFile())) {
                 continue;
             }
@@ -411,66 +364,78 @@ void FileUndoManager::undo()
         itemsToDelete.append(d->m_current.m_dst);
     }
     if (!itemsToDelete.isEmpty()) {
-        if (!d->m_uiInterface->confirmDeletion(itemsToDelete)) {
+        AskUserActionInterface *askUserInterface = nullptr;
+        d->m_uiInterface->virtual_hook(UiInterface::HookGetAskUserActionInterface, &askUserInterface);
+        if (askUserInterface) {
+            if (!d->m_connectedToAskUserInterface) {
+                d->m_connectedToAskUserInterface = true;
+                QObject::connect(askUserInterface, &KIO::AskUserActionInterface::askUserDeleteResult,
+                                 this, [=](bool allowDelete) {
+                    if (allowDelete) {
+                        d->startUndo();
+                    }
+                });
+            }
+
+            // Because undo can happen with an accidental Ctrl-Z, we want to always confirm.
+            askUserInterface->askUserDelete(itemsToDelete, KIO::AskUserActionInterface::Delete,
+                                            KIO::AskUserActionInterface::ForceConfirmation,
+                                            d->m_uiInterface->parentWidget());
             return;
         }
-    } else if (commandType == FileUndoManager::Copy) {
-        d->slotPop();
-        return;
     }
 
-    d->slotPop();
-    d->slotLock();
+    d->startUndo();
+}
 
-    d->m_dirCleanupStack.clear();
-    d->m_dirStack.clear();
-    d->m_dirsToUpdate.clear();
+void FileUndoManagerPrivate::startUndo()
+{
+    slotPop();
+    slotLock();
 
-    d->m_undoState = MOVINGFILES;
+    m_dirCleanupStack.clear();
+    m_dirStack.clear();
+    m_dirsToUpdate.clear();
+
+    m_undoState = MOVINGFILES;
 
     // Let's have a look at the basic operations we need to undo.
-    // While we're at it, collect all links that should be deleted.
-
-    it = opStack.begin();
-    while (it != opStack.end()) { // don't cache end() here, erase modifies it
-        bool removeBasicOperation = false;
-        BasicOperation::Type type = (*it).m_type;
+    auto &opQueue = m_current.m_opQueue;
+    for (auto it = opQueue.rbegin(); it != opQueue.rend(); ++it) {
+        const BasicOperation::Type type = (*it).m_type;
         if (type == BasicOperation::Directory && !(*it).m_renamed) {
             // If any directory has to be created/deleted, we'll start with that
-            d->m_undoState = MAKINGDIRS;
+            m_undoState = MAKINGDIRS;
             // Collect all the dirs that have to be created in case of a move undo.
-            if (d->m_current.isMoveCommand()) {
-                d->m_dirStack.push((*it).m_src);
+            if (m_current.isMoveCommand()) {
+                m_dirStack.push((*it).m_src);
             }
             // Collect all dirs that have to be deleted
             // from the destination in both cases (copy and move).
-            d->m_dirCleanupStack.prepend((*it).m_dst);
-            removeBasicOperation = true;
+            m_dirCleanupStack.prepend((*it).m_dst);
         } else if (type == BasicOperation::Link) {
-            d->m_fileCleanupStack.prepend((*it).m_dst);
-
-            removeBasicOperation = !d->m_current.isMoveCommand();
-        }
-
-        if (removeBasicOperation) {
-            it = opStack.erase(it);
-        } else {
-            ++it;
+            m_fileCleanupStack.prepend((*it).m_dst);
         }
     }
+    auto isBasicOperation = [this](const BasicOperation &op) {
+        return (op.m_type == BasicOperation::Directory && !op.m_renamed)
+                || (op.m_type == BasicOperation::Link && !m_current.isMoveCommand());
+    };
+    opQueue.erase(std::remove_if(opQueue.begin(), opQueue.end(), isBasicOperation), opQueue.end());
 
+    const FileUndoManager::CommandType commandType = m_current.m_type;
     if (commandType == FileUndoManager::Put) {
-        d->m_fileCleanupStack.append(d->m_current.m_dst);
+        m_fileCleanupStack.append(m_current.m_dst);
     }
 
-    qCDebug(KIO_WIDGETS) << "starting with" << undoStateToString(d->m_undoState);
-    d->m_undoJob = new UndoJob(d->m_uiInterface->showProgressInfo());
-    QMetaObject::invokeMethod(d, "undoStep", Qt::QueuedConnection);
+    qCDebug(KIO_WIDGETS) << "starting with" << undoStateToString(m_undoState);
+    m_undoJob = new UndoJob(m_uiInterface->showProgressInfo());
+    QMetaObject::invokeMethod(this, "undoStep", Qt::QueuedConnection);
 }
 
 void FileUndoManagerPrivate::stopUndo(bool step)
 {
-    m_current.m_opStack.clear();
+    m_current.m_opQueue.clear();
     m_dirCleanupStack.clear();
     m_fileCleanupStack.clear();
     m_undoState = REMOVINGDIRS;
@@ -496,7 +461,7 @@ void FileUndoManagerPrivate::slotResult(KJob *job)
         delete m_undoJob;
         stopUndo(false);
     } else if (m_undoState == STATINGFILE) {
-        BasicOperation op = m_current.m_opStack.last();
+        const BasicOperation op = m_current.m_opQueue.head();
         //qDebug() << "stat result for " << op.m_dst;
         KIO::StatJob *statJob = static_cast<KIO::StatJob *>(job);
         const QDateTime mtime = QDateTime::fromMSecsSinceEpoch(1000 * statJob->statResult().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, -1), Qt::UTC);
@@ -567,20 +532,15 @@ void FileUndoManagerPrivate::stepMakingDirectories()
 // deletes copied files, and restores trashed files.
 void FileUndoManagerPrivate::stepMovingFiles()
 {
-    if (!m_current.m_opStack.isEmpty()) {
-        BasicOperation op = m_current.m_opStack.last();
-        BasicOperation::Type type = op.m_type;
-
-        assert(op.m_valid);
-        if (type == BasicOperation::Directory) {
-            if (op.m_renamed) {
-                //qDebug() << "rename" << op.m_dst << op.m_src;
-                m_currentJob = KIO::rename(op.m_dst, op.m_src, KIO::HideProgressInfo);
-                m_undoJob->emitMoving(op.m_dst, op.m_src);
-            } else {
-                assert(0);    // this should not happen!
-            }
-        } else if (type == BasicOperation::Link) {
+    if (!m_current.m_opQueue.isEmpty()) {
+        const BasicOperation op = m_current.m_opQueue.head();
+        Q_ASSERT(op.m_valid);
+        if (op.m_type == BasicOperation::Directory) {
+            Q_ASSERT(op.m_renamed);
+            //qDebug() << "rename" << op.m_dst << op.m_src;
+            m_currentJob = KIO::rename(op.m_dst, op.m_src, KIO::HideProgressInfo);
+            m_undoJob->emitMoving(op.m_dst, op.m_src);
+        } else if (op.m_type == BasicOperation::Link) {
             //qDebug() << "symlink" << op.m_target << op.m_src;
             m_currentJob = KIO::symlink(op.m_target, op.m_src, KIO::Overwrite | KIO::HideProgressInfo);
         } else if (m_current.m_type == FileUndoManager::Copy) {
@@ -598,7 +558,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
         } else if (m_current.isMoveCommand()
                    || m_current.m_type == FileUndoManager::Trash) {
             //qDebug() << "file_move" << op.m_dst << op.m_src;
-            m_currentJob = KIO::file_move(op.m_dst, op.m_src, -1, KIO::Overwrite | KIO::HideProgressInfo);
+            m_currentJob = KIO::file_move(op.m_dst, op.m_src, -1, KIO::HideProgressInfo);
             m_currentJob->uiDelegateExtension()->createClipboardUpdater(m_currentJob, JobUiDelegateExtension::UpdateContent);
             m_undoJob->emitMoving(op.m_dst, op.m_src);
         }
@@ -607,7 +567,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
             m_currentJob->setParentJob(m_undoJob);
         }
 
-        m_current.m_opStack.removeLast();
+        m_current.m_opQueue.dequeue();
         // The above KIO jobs are lowlevel, they don't trigger KDirNotify notification
         // So we need to do it ourselves (but schedule it to the end of the undo, to compress them)
         QUrl url = op.m_dst.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
@@ -624,13 +584,13 @@ void FileUndoManagerPrivate::stepRemovingLinks()
 {
     //qDebug() << "REMOVINGLINKS";
     if (!m_fileCleanupStack.isEmpty()) {
-        QUrl file = m_fileCleanupStack.pop();
+        const QUrl file = m_fileCleanupStack.pop();
         //qDebug() << "file_delete" << file;
         m_currentJob = KIO::file_delete(file, KIO::HideProgressInfo);
         m_currentJob->setParentJob(m_undoJob);
         m_undoJob->emitDeleting(file);
 
-        QUrl url = file.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
+        const QUrl url = file.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
         addDirToUpdate(url);
     } else {
         m_undoState = REMOVINGDIRS;
@@ -658,12 +618,11 @@ void FileUndoManagerPrivate::stepRemovingDirectories()
             m_undoJob->emitResult();
             m_undoJob = nullptr;
         }
-        QList<QUrl>::ConstIterator it = m_dirsToUpdate.constBegin();
-        for (; it != m_dirsToUpdate.constEnd(); ++it) {
-            //qDebug() << "Notifying FilesAdded for " << *it;
-            org::kde::KDirNotify::emitFilesAdded((*it));
+        for (const QUrl &url : qAsConst(m_dirsToUpdate)) {
+            //qDebug() << "Notifying FilesAdded for " << url;
+            org::kde::KDirNotify::emitFilesAdded(url);
         }
-        emit q->undoJobFinished();
+        Q_EMIT q->undoJobFinished();
         slotUnlock();
     }
 }
@@ -679,30 +638,30 @@ void FileUndoManagerPrivate::slotPush(QByteArray data)
 
 void FileUndoManagerPrivate::pushCommand(const UndoCommand &cmd)
 {
-    m_commands.append(cmd);
-    emit q->undoAvailable(true);
-    emit q->undoTextChanged(q->undoText());
+    m_commands.push(cmd);
+    Q_EMIT q->undoAvailable(true);
+    Q_EMIT q->undoTextChanged(q->undoText());
 }
 
 void FileUndoManagerPrivate::slotPop()
 {
-    m_commands.removeLast();
-    emit q->undoAvailable(q->undoAvailable());
-    emit q->undoTextChanged(q->undoText());
+    m_commands.pop();
+    Q_EMIT q->undoAvailable(q->isUndoAvailable());
+    Q_EMIT q->undoTextChanged(q->undoText());
 }
 
 void FileUndoManagerPrivate::slotLock()
 {
-//  assert(!m_lock);
+//  Q_ASSERT(!m_lock);
     m_lock = true;
-    emit q->undoAvailable(q->undoAvailable());
+    Q_EMIT q->undoAvailable(q->isUndoAvailable());
 }
 
 void FileUndoManagerPrivate::slotUnlock()
 {
-//  assert(m_lock);
+//  Q_ASSERT(m_lock);
     m_lock = false;
-    emit q->undoAvailable(q->undoAvailable());
+    Q_EMIT q->undoAvailable(q->isUndoAvailable());
 }
 
 QByteArray FileUndoManagerPrivate::get() const
@@ -796,8 +755,14 @@ bool FileUndoManager::UiInterface::showProgressInfo() const
     return d->m_showProgressInfo;
 }
 
-void FileUndoManager::UiInterface::virtual_hook(int, void *)
+void FileUndoManager::UiInterface::virtual_hook(int id, void *data)
 {
+    if (id == HookGetAskUserActionInterface) {
+        auto *p = static_cast<AskUserActionInterface**>(data);
+        static KJobUiDelegate *delegate = KIO::createDefaultJobUiDelegate();
+        static auto *askUserInterface = delegate ? delegate->findChild<AskUserActionInterface *>(QString(), Qt::FindDirectChildrenOnly) : nullptr;
+        *p = askUserInterface;
+    }
 }
 
 #include "moc_fileundomanager_p.cpp"
