@@ -1,30 +1,18 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 David Smith  <dsmith@algonet.se>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 David Smith <dsmith@algonet.se>
 
     This class was inspired by a previous KUrlCompletion by
-    Henner Zeller <zeller@think.de>
+    SPDX-FileContributor: Henner Zeller <zeller@think.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KURLCOMPLETION_H
 #define KURLCOMPLETION_H
 
 #include "kiowidgets_export.h"
-#include <kcompletion.h>
+#include <KCompletion>
 #include <kio/udsentry.h>
 #include <QString>
 
@@ -170,14 +158,14 @@ public:
                                 bool replaceHome, bool replaceEnv = true);
 
     /**
-     * Sets the mimetype filters for the file dialog.
+     * Sets the MIME type filters for the file dialog.
      * @see QFileDialog::setMimeTypeFilters()
      * @since 5.38
      */
     void setMimeTypeFilters(const QStringList &mimeTypes);
 
     /**
-     * Returns the mimetype filters for the file dialog.
+     * Returns the MIME type filters for the file dialog.
      * @see QFileDialog::mimeTypeFilters()
      * @since 5.38
      */
